        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 27 <strong>control</strong><br>0,2,4,7,13,14,16,17,18,19,21,23,24,26,27,28,29,30,32,33,38,40,41,42,43,46,48';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 24 <br>1,3,5,6,8,9,10,11,12,15,20,22,25,31,34,35,36,37,39,44,45,47,49,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 27 <strong>control</strong><br>0,2,4,7,13,14,16,17,18,19,21,23,24,26,27,28,29,30,32,33,38,40,41,42,43,46,48';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 24 <br>1,3,5,6,8,9,10,11,12,15,20,22,25,31,34,35,36,37,39,44,45,47,49,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 27 <strong>control</strong><br>0,2,4,7,13,14,16,17,18,19,21,23,24,26,27,28,29,30,32,33,38,40,41,42,43,46,48';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 24 <br>1,3,5,6,8,9,10,11,12,15,20,22,25,31,34,35,36,37,39,44,45,47,49,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 27 <strong>control</strong><br>0,2,4,7,13,14,16,17,18,19,21,23,24,26,27,28,29,30,32,33,38,40,41,42,43,46,48';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 24 <br>1,3,5,6,8,9,10,11,12,15,20,22,25,31,34,35,36,37,39,44,45,47,49,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 27 <strong>control</strong><br>0,2,4,7,13,14,16,17,18,19,21,23,24,26,27,28,29,30,32,33,38,40,41,42,43,46,48';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260625 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>1</strong> miembros: 24 <br>1,3,5,6,8,9,10,11,12,15,20,22,25,31,34,35,36,37,39,44,45,47,49,50';}
}
